@@ -1,7 +1,7 @@
 package App::podtohtml;
 
-our $DATE = '2017-01-31'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-02-06'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,7 @@ _
 If not found, will search in for .pod or .pm files in `@INC`.
 
 _
-            schema => 'perl_modname_or_filename*',
+            schema => 'perl::pod_or_pm_filename*',
             default => '-',
             pos => 0,
         },
@@ -76,20 +76,8 @@ sub podtohtml {
 
     my ($fh, $tempoutfile) = File::Temp::tempfile();
 
-    if ($infile eq '-') {
-    } else {
-        if (!(-f $infile)) {
-            # try searching in @INC
-            require Module::Path::More;
-            (my $mod = $infile) =~ s![/.]!::!g;
-            my $path = Module::Path::More::module_path(
-                module => $mod, find_pod => 1, find_pmc => 0,
-            );
-            $infile = $path if $path;
-        }
-        unless (-f $infile) {
-            return [404, "No such file '$infile'"];
-        }
+    unless (-f $infile) {
+        return [404, "No such file '$infile'"];
     }
 
     Pod::Html::pod2html(
@@ -128,12 +116,16 @@ App::podtohtml - Convert POD to HTML
 
 =head1 VERSION
 
-This document describes version 0.001 of App::podtohtml (from Perl distribution App-podtohtml), released on 2017-01-31.
+This document describes version 0.002 of App::podtohtml (from Perl distribution App-podtohtml), released on 2017-02-06.
 
 =head1 FUNCTIONS
 
 
-=head2 podtohtml(%args) -> [status, msg, result, meta]
+=head2 podtohtml
+
+Usage:
+
+ podtohtml(%args) -> [status, msg, result, meta]
 
 Convert POD to HTML.
 
@@ -168,7 +160,7 @@ Arguments ('*' denotes required arguments):
 
 Instead of outputing HTML to STDOUT/file, view it in browser.
 
-=item * B<infile> => I<perl_modname_or_filename> (default: "-")
+=item * B<infile> => I<perl::pod_or_pm_filename> (default: "-")
 
 Input file (POD).
 
